@@ -10,12 +10,12 @@ from . import framing, common, stream, detect, sampling
 log = logging.getLogger(__name__)
 
 
-def send(config, src, dst, gain=1.0):
+def send(config, src, dst, gain=1.0, extra_silence=0.0):
     sender = _send.Sender(dst, config=config, gain=gain)
     Fs = config.Fs
 
     # pre-padding audio with silence (priming the audio sending queue)
-    sender.write(np.zeros(int(Fs * config.silence_start)))
+    sender.write(np.zeros(int(Fs * (config.silence_start + extra_silence))))
 
     sender.start()
 
@@ -59,10 +59,11 @@ def recv(config, src, dst, dump_audio=None, pylab=None):
         gain = 1.0 / amplitude
         log.debug('Gain correction: %.3f', gain)
 
-        sampler = sampling.Sampler(signal, sampling.Interpolator(), freq=freq)
+        sampler = sampling.Sampler(signal, sampling.defaultInterpolator,
+                                   freq=freq)
         receiver.run(sampler, gain=1.0/amplitude, output=dst)
         return True
-    except BaseException:
+    except BaseException:  # pylint: disable=broad-except
         log.exception('Decoding failed')
         return False
     finally:
