@@ -1,7 +1,7 @@
-from amodem import alsa, config
-
 import mock
 
+from .. import alsa, config
+
 
 def test_alsa():
     interface = alsa.Interface(config=config.fastest())
