@@ -1,8 +1,8 @@
-from amodem import audio, config
-
 import mock
 import pytest
 
+from .. import audio, config
+
 
 def test():
     length = 1024
@@ -31,4 +31,4 @@ def test():
             s.close()
 
         with pytest.raises(Exception):
-            interface._error_check(1)
+            interface._error_check(1)  # pylint: disable=protected-access
