@@ -1,7 +1,7 @@
-from amodem import common
-from amodem import config
 import numpy as np
 
+from .. import common, config
+
 
 def iterlist(x, *args, **kwargs):
     x = np.array(x)
