@@ -1,9 +1,10 @@
-from amodem import framing
-import random
 import itertools
+import random
 
 import pytest
 
+from .. import framing
+
 
 def concat(iterable):
     return bytearray(itertools.chain.from_iterable(iterable))
