@@ -1,7 +1,8 @@
-from amodem import stream
 import subprocess as sp
 import sys
 
+from .. import stream
+
 script = br"""
 import sys
 import time
